<?php

namespace Drupal\component_builder;

use Drupal\Component\Plugin\DependentPluginInterface;

/**
 * Provides an interface for a navigation component plugin.
 */
interface ComponentBuilderPluginInterface extends DependentPluginInterface {

  /**
   * Returns the component label that is displayed in backend.
   */
  public function label(): string;

  /**
   * Returns the template name this component is using.
   */
  public function getTemplateName(): string;

  /**
   * Returns the directory of component.
   */
  public function getDirectory(): string;

  /**
   * Prepare the necessary variables for template_preprocess_node().
   */
  public function prepareVariables(array &$variables): void;

  /**
   * Returns a list of libraries this plugin requires.
   *
   * These libraries will be attached to the component on which the
   * component is being loaded.
   *
   * @return array
   *   An array of libraries suitable for usage in a render API #attached
   *   property.
   */
  public function getLibraries(): array;

  /**
   * Returns a name of module.
   *
   * @return string
   *   Module name contain component.
   */
  public function getModule(): string;

  /**
   * Returns path of component.
   */
  public function getComponentPath(): string;

  /**
   * Returns path template of component.
   */
  public function getTemplatePath(): string;

}
