<?php

namespace Drupal\component_builder\Plugin\ComponentBuilder;

use Drupal\component_builder\Annotation\ComponentBuilder;
use Drupal\component_builder\ComponentBuilderBase;
use Drupal\component_builder\Entity\ComponentWrapper;

/**
 * Provides 'Composite' component.
 *
 * @ComponentBuilder(
 *   id = "composite",
 *   label = @Translation("Composite"),
 *   group = @Translation("General components"),
 *   template = "composite"
 * )
 */
class Composite extends ComponentBuilderBase {

  /**
   * {@inheritdoc}
   */
  public function getTemplatePath(): string {
    return $this->getComponentPath() . '/component_' . $this->getPluginId() . '/templates';
  }

  /**
   * {@inheritdoc}
   */
  public function prepareVariables(array &$variables): void {
    if (isset($variables['elements']['#component_wrapper'])) {
      $component_wrapper = $variables['elements']['#component_wrapper'];
      if ($component_wrapper instanceof ComponentWrapper) {
        $number = 2;
        $class_options = '6-6';
        $styles = $component_wrapper->get('field_styles')->value;
        $options = $component_wrapper->get('field_options')->value;
        if ($styles) {
          $styles = json_decode($styles, TRUE);
          if (isset($styles["layout"])) {
            $class_options = str_replace('column-', '', $styles["layout"]);
          }

          $layout = $styles['layout'];
          $layout = str_replace('column_', '', $layout);
          $layout = explode('_', $layout);
        }
        else {
          $layout = [12,12,12];
        }

        if ($options) {
          $options = json_decode($options, TRUE);
          if (isset($options["column"])) {
            $number = (int) $options["column"];
          }

          if (isset($options['column'])) {
            $column = $options['column'];
            if ($column == 1) {
              $variables['left_column_with'] = 12;
            }
            elseif ($column == 2) {
              $variables['left_column_with'] = $layout[0];
              $variables['right_column_with'] = $layout[1];
            }
            elseif ($column == 3) {
              $variables['left_column_with'] = $layout[0];
              $variables['middle_column_with'] = $layout[1];
              $variables['right_column_with'] = $layout[2];
            }
          }
        }
        $variables['attributes']['data-number-columns'][] = $number;
        $variables['attributes']['data-column-class'][] = $class_options;
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getLibraries(): array {
    return [
      'css' => [
        'theme' => [
          'components/component_composite/assets/style.css' => []
        ]
      ],
      'js' => [
        'components/component_composite/assets/style.js' => []
      ],
      "version" => "VERSION",
    ];
  }

}
